import React, { useState, useEffect, useRef, useMemo } from 'react';
import { Form, Select, Button, Table, Input, Checkbox, Divider, Tabs } from 'antd';
import { connect } from 'dva';
import AuditNodeModal from './AuditNodeModal';
import AuditModal from './AuditModal';
import styles from './Audit.less';
import router from 'umi/router';
import Flow, { FLOW_TYPE } from '@/components/Flow';
import AuditForm from '@/components/AuditForm';
import { async } from '@antv/x6/lib/registry/marker/async';
const { Option } = Select;
const { TabPane } = Tabs;

const FLOWID = 2;

function Audit(props) {
  const {
    roleList,
    currentItem,
    dispatch,
    formItems,
    formData,
    flowDetail,
    simpleFlowDteail,
    currentUser,
    loading,
  } = props;
  const ref = useRef();
  const permission = currentUser.Permission;

  const curItem = useMemo(() => {
    let item = localStorage.getItem('currentAudit');
    return JSON.stringify(currentItem) == '{}' ? JSON.parse(item) : currentItem;
  }, [currentItem, localStorage.getItem('currentAudit')]);

  const editMode = useMemo(() => {
    // 判断是否有权限
    if (permission['func-01-point-bom-flow']) {
      return 1;
    }
    // 判断是否为创建者
    if (currentUser.IsSuper) {
      return 1;
    }

    return 2;
  }, [permission, flowDetail]);

  useEffect(() => {
    dispatch({
      type: 'flow/queryProcessFlows',
      payload: { ids: Number(curItem.id) },
    });
    dispatch({
      type: 'user/getRoleList',
    });
    dispatch({
      type: 'user/fetch',
    });

    dispatch({
      type: 'user/fetchDepV2',
    });
  }, []);

  const onChange = values => {
    dispatch({
      type: 'xflow/save',
      payload: {
        formData: values,
      },
    });
  };

  const handleSaveClick = async () => {
    //只修改表单不渲染xflow getGraphData方法找不到，保存接口返回的flowDetail数据
    if (!ref.current?.getGraphData) {
      let param = {
        // name: curItem.name,
        id: Number(curItem.id),
        form_json: JSON.stringify(formItems),
        process_json: JSON.stringify(flowDetail),
        process_simple_json: simpleFlowDteail,
      };
      dispatch({ type: 'flow/saveAuditFlowInfo', payload: param });
      return;
    }
    await ref.current?.getGraphData?.((data, simpleNodes) => {
      let param = {
        // name: curItem.name,
        id: Number(curItem.id),
        form_json: JSON.stringify(formItems),
        process_json: data,
        process_simple_json: simpleNodes,
      };
      localStorage.saveAuditFlowInfo = JSON.stringify(param)
      dispatch({ type: 'flow/saveAuditFlowInfo', payload: param });
    });
  };
  return (
    <div style={{ position: 'relative' }}>
      <p>{curItem.name}</p>
      <Tabs defaultActiveKey="1">
        <TabPane tab="表单设计" key="1">
          <AuditForm value={formData} onChange={values => onChange(values)} />
        </TabPane>
        <TabPane tab="流程控制" key="2">
          <Flow
            meta={{ type: 'edit', editMode, flowId: curItem.id }}
            flowDetail={flowDetail}
            ref={ref}
          />
        </TabPane>
      </Tabs>
      <Button
        loading={loading['flow/saveAuditFlowInfo']}
        type="primary"
        onClick={handleSaveClick}
        style={{ position: 'absolute', right: 0, top: 0 }}
      >
        保存
      </Button>
    </div>
  );
}
export default connect(({ flow, loading, user, xflow }) => ({
  roleList: flow.roleList,
  currentItem: flow.current,
  loading: loading.effects,
  formItems: xflow.formData,
  flowDetail: flow.flowDetail,
  formData: flow.formData,
  currentUser: user.currentUser,
  simpleFlowDteail: flow.simpleFlowDteail,
}))(Audit);
